@@ -452,24 +452,20 @@ init_module(void)
 void
 cleanup_module(void)
 {
-   int retval;
-
    unregister_ioctl32_handlers();
 
    /*
     * XXX smp race?
     */
 #ifdef VMX86_DEVEL
-   retval = unregister_chrdev(linuxState.major, linuxState.deviceName);
+   unregister_chrdev(linuxState.major, linuxState.deviceName);
 #else
-   retval = misc_deregister(&linuxState.misc);
+   if (misc_deregister(&linuxState.misc)) {
+      Warning("Module %s: error unregistering\n", linuxState.deviceName);
+   }
 #endif
 
-   if (retval) {
-      Warning("Module %s: error unregistering\n", linuxState.deviceName);
-   } else {
-      Log("Module %s: unloaded\n", linuxState.deviceName);
-   }
+   Log("Module %s: unloaded\n", linuxState.deviceName);
 
    compat_del_timer_sync(&linuxState.pollTimer);
    compat_del_timer_sync(&tscTimer);
@@ -1655,7 +1651,11 @@ pageLockEnd:
 	  current->fsuid == current->uid &&
           current->egid == current->gid &&
 	  current->fsgid == current->gid) {
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 4, 7)
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 23) || defined(MMF_DUMPABLE)
+         /* Dump core, readable by user. */
+         set_bit(MMF_DUMPABLE, &current->mm->flags);
+         clear_bit(MMF_DUMP_SECURELY, &current->mm->flags);
+#elif LINUX_VERSION_CODE >= KERNEL_VERSION(2, 4, 7)
 	 current->mm->dumpable = 1;
 #else
 	 current->dumpable = 1;
